@@ -1,7 +1,9 @@
 
 ###################################################################################
 #
-#   Embperl - Copyright (c) 1997-2010 Gerald Richter / ECOS
+#   Embperl - Copyright (c) 1997-2008 Gerald Richter / ecos gmbh  www.ecos.de
+#   Embperl - Copyright (c) 2008-2015 Gerald Richter
+#   Embperl - Copyright (c) 2015-2023 actevy.io
 #
 #   You may distribute under the terms of either the GNU General Public
 #   License or the Artistic License, as specified in the Perl README file.
@@ -10,8 +12,6 @@
 #   IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 #   WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 #
-#   $Id: App.pm 294776 2005-09-25 13:43:39Z richter $
-#
 ###################################################################################
  
 
@@ -21,6 +21,8 @@ package Embperl::App ;
 use strict ;
 use vars qw{%Recipes} ;
 
+no warnings "uninitialized" ;
+
 # ---------------------------------------------------------------------------------
 #
 #   Get/create named recipe
@@ -295,7 +297,7 @@ __END__
 
 =head1 NAME
 
-Embperl base class for application objects
+Embperl::App - Embperl base class for application objects
 
 =head1 SYNOPSIS
 
