@@ -1,6 +1,8 @@
 ###################################################################################
 #
-#   Embperl - Copyright (c) 1997-2010 Gerald Richter / ecos gmbh   www.ecos.de
+#   Embperl - Copyright (c) 1997-2008 Gerald Richter / ecos gmbh  www.ecos.de
+#   Embperl - Copyright (c) 2008-2015 Gerald Richter
+#   Embperl - Copyright (c) 2015-2023 actevy.io
 #
 #   You may distribute under the terms of either the GNU General Public
 #   License or the Artistic License, as specified in the Perl README file.
@@ -35,6 +37,8 @@ sub is_hidden
     return  1 ;
     }
 
+sub show_control { show (@_) ; }
+sub show_control_readonly { show (@_) ; }
 
 
 1 ;
@@ -88,7 +92,7 @@ Will be used as name for the hidden input field.
 
 =head1 Author
 
-G. Richter (richter@dev.ecos.de), A. Beckert (beckert@ecos.de)
+G. Richter (richter at embperl dot org), A. Beckert
 
 =head1 See Also
 
