@@ -1,7 +1,9 @@
 
 ###################################################################################
 #
-#   Embperl - Copyright (c) 1997-2010 Gerald Richter / ECOS
+#   Embperl - Copyright (c) 1997-2008 Gerald Richter / ecos gmbh  www.ecos.de
+#   Embperl - Copyright (c) 2008-2015 Gerald Richter
+#   Embperl - Copyright (c) 2015-2023 actevy.io
 #
 #   You may distribute under the terms of either the GNU General Public
 #   License or the Artistic License, as specified in the Perl README file.
@@ -10,8 +12,6 @@
 #   IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 #   WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 #
-#   $Id: Mail.pm 294756 2005-08-07 00:03:03Z richter $
-#
 ###################################################################################
  
 package Embperl::Syntax::Mail ;
@@ -85,10 +85,12 @@ sub Init
                     use Embperl::Mail ;
 
                     my $txt = XML::Embperl::DOM::Node::iChildsText (%$n%) ;
+                    my @errors ;
                     $? = Embperl::Mail::Execute (
                         {
                         'input'       => \$txt,
                         'inputfile'   => 'mail',
+                        'errors'      => \@errors,
                         'syntax'      => 'Text',
                         'from'        => %&'from%,
                         'to'          => %&'to%,
@@ -101,6 +103,7 @@ sub Init
                         'maildebug'   => %&'maildebug%,
                         'mailheaders' => [ (( %&'content-type% ) ? ('Content-Type: '.%&'content-type%) : ()) ],
                         }) ;
+                    print STDERR join ('; ', @errors) if (@errors) ;
                     }
                   },
                 stackname   => 'mail_send',
@@ -126,13 +129,13 @@ __END__
 
 =head1 NAME
 
-Embperl Taglib for sending mail
+Embperl::Syntax::Mail - tag library for sending mail
 
 =head1 SYNOPSIS
 
   [$ syntax + Mail $]
 
-  <mail:send to="richter@ecos.de" subject="Testmail">
+  <mail:send to="richter at embperl dot org" subject="Testmail">
     Hi,
     this is a test for a new mail tag
     it is send at [+ scalar(localtime) +]
@@ -183,7 +186,7 @@ On success it sets C<$?> to zero, otherwise to a value other then zero.
 
 =head1 Author
 
-Gerald Richter <richter@dev.ecos.de>
+Gerald Richter <richter at embperl dot org>
 
 =head1 See Also
 
